# WORKFLOW REST SERVICE
Service in charge of workflow

Set up to develop
1. Install with: 
'python setup.py install'

2. Start database server 
'pg_ctl -D /usr/local/var/postgres/ start'

3. Create flask_api database 
'createdb flask_dev'

4. Run api
'python manage.py run'